#!/usr/bin/perl -w

use strict;
use Getopt::Long;
use File::Copy;
use POSIX qw(strftime);

# First-level directory on the Compact Flash
my $mount_dir = '/mnt/usb';
# Date of Picture Dump
my $dump_date = strftime('%Y%m%d-%H%M%S',localtime(time));
# Directory to store the dump
my $dump_dir = 'pd-'.$dump_date;
# Copy or move files from Compact Flash?
my $copy = 1;
# Autorotate images based on EXIF data?
my $rotate = 1;
# Print help and exit?
my $help = 0;

GetOptions (
			"dump=s" => \$dump_dir,
			"mount=s" => \$mount_dir,
			"copy"   => \$copy,
			"rotate" => \$rotate,
			"help"   => \$help,
		);

if ($help) {
	print "\n";
	print "Usage: $0 [OPTIONS]\n";
	print "Options:\n";
	print "\n";
	print " --dump DumpName\n";
	print " --dump=DumpName\n";
	print "   Use 'DumpName' directory. Otherwise the date-specific\n";
	print "   directory will be used (and created if does not exist).\n";
	print "\n";
	print " --mount MountPoint\n";
	print " --mount=MountPoint\n";
	print "   Do 'mount MountPoint' and 'umount MountPoint' befor and after\n";
	print "   image dumping.\n";
	print "\n";
	print " --copy\n";
	print "   Copy images from Compact Flash instead of moving them.\n";
	print "\n";
	print " --rotate\n";
	print "   Rotate images based on EXIF data.  Requires jhead.\n";
	print "   Get it from http://www.sentex.net/~mwandel/jhead/ \n";
	print "\n";
	print " --help\n";
	print "   Print this help message.\n";
	print "\n";
	exit(0);
}

$mount_dir =~ s#/+$##;
system ("mount $mount_dir") == 0
	or die "Couldn't mount $mount_dir\n";

my $cf_dir = $mount_dir . '/dcim';
opendir(CF, $cf_dir) or die "Couldn't list $cf_dir : $!\n";

# Create Picture Dump directory if it does not exist.
if (! -e $dump_dir) {
	print "Creating Picture Dump $dump_dir\n";
	mkdir($dump_dir);
}

# Go through all Canon image directories
foreach my $dir (sort readdir(CF)) {
	# Only copy images from the recognized Canon image directories
	if ($dir =~ m/^\d+canon$/) {
		my $img_dir = $cf_dir . '/' . $dir;
		print "Getting files from $img_dir\n";
		opendir(IMGDIR, $img_dir) or die "Couldn't list $img_dir : $!";
		foreach my $file (sort readdir(IMGDIR)) {
			my $img_file = $img_dir . '/' . $file;
			if ($file =~ m/^[A-z]{3}_[0-9]{4}\.jpg/) {
				my $new_img = $dump_dir . '/' . $file;
				# Copy or move files from Compact Flash
				print "Copying $img_file to $new_img\n";
				copy($img_file,$new_img) or die "Couldn't copy $img_file : $!";
				unlink($img_file) or die "Couldn't remove $img_file : $!" unless ($copy);
				# Rotate
				system("jhead -autorot $new_img") if ($rotate);
			}
			else {
				print "Skipping file $img_file due to bad name\n";
			}
		}
		closedir(IMGDIR);
		unless ($copy) {
			unlink($img_dir) or die "Couldn't remove $img_dir : $!";
		}
	}
}
closedir(CF);

system ("umount $mount_dir") == 0
	or die "Couldn't umount $mount_dir\n";

